@@ -3,7 +3,8 @@ from itertools import (accumulate,
                        chain,
                        groupby,
                        repeat)
-from typing import (Iterable,
+from typing import (FrozenSet,
+                    Iterable,
                     List,
                     Optional,
                     Sequence,
@@ -28,12 +29,12 @@ from .quad_edge import (QuadEdge,
                         edge_to_neighbours,
                         edge_to_non_adjacent_vertices,
                         edges_with_opposites)
-from .sweep import sweep
 from .utils import (ceil_log2,
                     contour_to_segments,
                     flatten,
                     normalize_contour,
                     pairwise,
+                    to_clockwise_contour,
                     to_min_max,
                     to_unique_objects)
 
@@ -55,7 +56,7 @@ class Triangulation:
     def __init__(self, left_edge: QuadEdge, right_edge: QuadEdge) -> None:
         self.left_edge = left_edge
         self.right_edge = right_edge
-        self._triangular_holes_vertices = set()
+        self._triangular_holes_vertices = set()  # type: Set[FrozenSet[Point]]
 
     __repr__ = generate_repr(__init__)
 
@@ -122,22 +123,19 @@ class Triangulation:
         if not holes:
             return
         events_queue = EventsQueue()
-        for hole in holes:
-            for segment in contour_to_segments(hole):
-                events_queue.register_segment(segment,
-                                              from_left=True)
         for edge in self._to_unique_inner_edges():
             events_queue.register_edge(edge,
-                                       from_left=False)
-        hole_segments_endpoints, candidates = set(), []
-        for event in sweep(events_queue):
-            if event.from_left:
-                hole_segments_endpoints.add(frozenset(event.segment))
-            elif event.in_intersection:
-                candidates.append(event.edge)
-        for edge in candidates:
-            if edge.endpoints not in hole_segments_endpoints:
-                self.delete(edge)
+                                       from_left=True,
+                                       is_counterclockwise_contour=True)
+        for hole in holes:
+            for segment in contour_to_segments(to_clockwise_contour(hole)):
+                events_queue.register_segment(
+                        segment,
+                        from_left=False,
+                        is_counterclockwise_contour=False)
+        for event in events_queue.sweep():
+            if event.from_left and event.inside:
+                self.delete(event.edge)
         self._triangular_holes_vertices.update(frozenset(hole)
                                                for hole in holes
                                                if len(hole) == 3)
