@@ -1,5 +1,3 @@
-from typing import Optional
-
 from reprit.base import generate_repr
 from robust.angular import Orientation
 
@@ -21,6 +19,8 @@ class YNode(Node):
         self.below._add_parent(self)
         self.above._add_parent(self)
 
+    __repr__ = generate_repr(__init__)
+
     @property
     def height(self) -> int:
         return max(self.below.height, self.above.height) + 1
@@ -34,14 +34,12 @@ class YNode(Node):
         else:
             return Location.BOUNDARY
 
-    __repr__ = generate_repr(__init__)
-
     def search_edge(self, edge: Edge) -> Trapezoid:
         return (self.above
                 if self.edge < edge
                 else self.below).search_edge(edge)
 
-    def _replace_child(self, current: 'Node', replacement: 'Node') -> None:
+    def _replace_child(self, current: Node, replacement: Node) -> None:
         if self.below is current:
             self.below = replacement
         else:
